"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lens_1 = require("./lens");
describe("with deep lens and object", function () {
    var testObj = {
        a: {
            b: {
                c: "d"
            }
        }
    };
    var testLens = lens_1.idLens();
    var deepLens = testLens
        .thenKeyOr("a", { b: { c: "fallback" } })
        .thenKey("b")
        .thenKey("c");
    test("get a value deep", function () {
        expect(deepLens.get(testObj)).toBe("d");
    });
    test("set a value deeply without changing everything", function () {
        expect(deepLens.set("d1")(testObj)).toEqual({
            a: {
                b: {
                    c: "d1"
                }
            }
        });
        expect(testObj).toEqual({
            a: {
                b: {
                    c: "d"
                }
            }
        });
    });
    test("update a value deeply without changing everything", function () {
        expect(deepLens.update(function (x) { return x + "1"; })(testObj)).toEqual({
            a: {
                b: {
                    c: "d1"
                }
            }
        });
        expect(testObj).toEqual({
            a: {
                b: {
                    c: "d"
                }
            }
        });
    });
    test("update with identity returns original", function () {
        expect(deepLens.update(function (x) { return x; })(testObj)).toBe(testObj);
        expect(testObj).toEqual({
            a: {
                b: {
                    c: "d"
                }
            }
        });
    });
});
describe("with array", function () {
    var testObj = [0, 1];
    var testLens = lens_1.idLens();
    var deepLens = testLens.thenKey("length");
    test("get a length from list", function () {
        expect(deepLens.get(testObj)).toBe(2);
    });
});
describe("with deep lens and object that is broken", function () {
    var testGood = {
        a: {
            b: {
                c: "c value"
            }
        }
    };
    var testLens = lens_1.idLens();
    var deepLens = testLens
        .thenKey("a")
        .thenKey("b")
        .thenKeyOr("c", "f");
    test("get a value deep", function () {
        expect(deepLens.get(undefined)).toBe("f");
    });
    test("set a value deep", function () {
        expect(testLens.thenKey("a").set(testGood.a)({ undefined: undefined })).toEqual(testGood);
    });
    test("set a shallow deep", function () {
        expect(testLens.set(testGood)(undefined)).toEqual(testGood);
    });
    test("get a value deep with thenKeyOr", function () {
        expect(testLens.thenKeyOr("a", testGood.a).get({})).toBe(testGood.a);
    });
});
//# sourceMappingURL=lens.spec.js.map